@@ -379,7 +379,7 @@ def test_IVData_02(datadir):
 
 
 def test_IVData_03(datadir):
-    """ make schema a bit more complex: add generic keys """
+    """make schema a bit more complex: add generic keys"""
     indir, outdir = datadir
     data = IVData()
     data.read_excel(os.path.join(indir, "test_02.xlsx"))
@@ -635,7 +635,12 @@ def test_IVData_06_units(datadir):
     for tabname in data_imp._data:
         df_imp = data_imp.convert_to(tabname)  # .pint.to_base_units()
         df_si = data_SI.convert_to(tabname)  # .pint.to_base_units()
-        assert pd.testing.assert_frame_equal(df_imp, df_si) is None
+        assert (
+            pd.testing.assert_frame_equal(
+                df_imp.pint.dequantify(), df_si.pint.dequantify()
+            )
+            is None
+        )
     # -------------------------------------------------------------------------
     # getunits
     assert data_SI.getunits("pressure", key="test_p_bar") == "MPa"
@@ -716,13 +721,13 @@ def test_IVData_08_multi_cols_uniqueness(datadir):
     assert rep == {
         "WithPadding_failing": {
             ("rail_tag & x_loc & block_label", "?"): [
-                "value " "{'RBL12 & " "3800.0 & " "s1'} is " "not " "unique"
+                "value {'RBL12 & 3800.0 & s1'} is not unique"
             ]
         },
         "asm_failing": {
             ("another", "?"): ["value {1.0} is not unique"],
             ("rail_tag & x_loc & block_label", "?"): [
-                "value {'RBL11 & " "3500 & RECARO1'} " "is not unique"
+                "value {'RBL11 & 3500.0 & RECARO1'} is not unique"
             ],
         },
     }
